==> haskell-hie-bios-0.12.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-9gpaLBLkBJL4T6ttsw1JqU
key:                  hie-bios-0.12.0-9gpaLBLkBJL4T6ttsw1JqU
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  31171914917c4375a66f1ca15cb4f4ad
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-9gpaLBLkBJL4T6ttsw1JqU
depends:
    aeson-2.1.2.1-HbpdIbO6AMR9AnrzgnqgHA base-4.16.4.0
    base16-bytestring-1.0.2.0-5p1GyxDIaDy1lbGSMKQW6W
    bytestring-0.11.4.0 co-log-core-0.3.2.3-8zp1GXi2e2ZKaRs4Qwgd5b
    conduit-1.3.6.1-z9AmGJDA6I5e741lyc8Fs
    conduit-extra-1.3.6-G3oiW8AJMcc50uCAlbWr4t
    cryptohash-sha1-0.11.101.0-Esb9UkSGPZbFjMjbNjT2D deepseq-1.4.6.1
    directory-1.3.6.2 exceptions-0.10.4
    extra-1.7.16-LvCisaJe0r84H5u45TnjVU
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    ghc-9.2.8 prettyprinter-1.7.1-HRQ8om4gnnHJhYdAhscFFG
    template-haskell-2.18.0.0 temporary-1.3-DbPriRXnwLpDQiIuk0AS91
    text-1.2.5.0 time-1.11.1.1 transformers-0.5.6.2
    unix-compat-0.7.2-GF6nRFHS9lJCc08eWtx5Md
    unordered-containers-0.2.20-FlJ58vN39MpAJvDCdrVy2C
    yaml-0.11.11.2-Ju1rTwvMcCZ1IiTntVi5SI

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hie-bios-0.12.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-3cNSiic4X439t4Jz0Q03Pt
key:                  hie-bios-0.12.0-3cNSiic4X439t4Jz0Q03Pt
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  aaba651b033e7631536bbc62c9b74e21
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-3cNSiic4X439t4Jz0Q03Pt
depends:
    aeson-2.1.2.1-GayFRV4oUv8L6a1HjAAkY base-4.16.4.0
    base16-bytestring-1.0.2.0-6am4HAEozKG2acVuW9SjDR
    bytestring-0.11.4.0 co-log-core-0.3.2.3-KHiGRWM1Oj6CMak12uvjyc
    conduit-1.3.6.1-K2hx0qHj7zU4rzCEb0M4w3
    conduit-extra-1.3.6-HzaMNX08a6i5ljb9TI1LbO
    cryptohash-sha1-0.11.101.0-6VInAVeGAVW9RCa4brCOWW deepseq-1.4.6.1
    directory-1.3.6.2 exceptions-0.10.4
    extra-1.7.16-H5PQt7NpxWADuVptudFzWc
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    ghc-9.2.8 prettyprinter-1.7.1-2MeKyKCMKbLJBZLGxdt1b7
    template-haskell-2.18.0.0 temporary-1.3-DlPEuuewvsKrIwgXPFoMU
    text-1.2.5.0 time-1.11.1.1 transformers-0.5.6.2
    unix-compat-0.7.2-Kcmk3eldTBQKVrrJpCSKjS
    unordered-containers-0.2.20-1oXBHIneMBm69TPTD2tYrr
    yaml-0.11.11.2-At8ToBbBrJ3C9NpJUqBQ6n

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
